package com.ximai.mes.pro.service;

import com.ximai.mes.pro.domain.ProUsage;

import java.util.List;

/**
 * title:
 * author:ZHT
 * date:2024/1/15
 * description:
 */
public interface IProUsageService {
    /**
     *  获取用途列表
     * @param proUsage 查询条件
     * @return 符合条件的用途列表
     */
    List<ProUsage> selectProUsageList(ProUsage proUsage);

    ProUsage selectProUsageByUsageId(Long usageId);

    String checkUsageCodeUnique(ProUsage proUsage);

    String checkUsageNameUnique(ProUsage proUsage);

    int insertProUsage(ProUsage proUsage);

    int updateProProcess(ProUsage proUsage);

    int deleteProUsageByUsageIds(Long[] usageIds);
}
